@@ -8,7 +8,7 @@ except ImportError:
         'Not found module named web. Please try the command \'pip install web.py\' to install web module.'
     )
 
-__version__ = '0.1.2'
+__version__ = '1.1.1'
 __author__ = 'BT.Q'
 __author_email__ = '2264481688@qq.com'
 
@@ -153,6 +153,13 @@ def mappings() -> tuple:
     """
     网站的所有站点储存，返回一个元组, 包含所有站点的定位符及其对应的类
     :rtype: tuple
+
+    >>> from webnew import *
+    >>> site('Hello')
+    >>> class greet: GET = lambda self: 'Hi, I\'m John.'
+    >>> newSite(greet, '/greet')
+    >>> print(mappings())
+    ('/', 'DefaultSite', '/greet', 'greet')
     """
     global __mappings
     return __mappings
